@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2000-2021 Vaclav Slavik
+ *  Copyright (C) 2000-2022 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -619,8 +619,12 @@ private:
                             wxOK | wxICON_ERROR
                         ));
                     err->SetExtendedMessage(DescribeCurrentException());
-                    err->ShowWindowModalThenDo([err](int){});
-                    break;
+                    // FIXME: can't use ShowWindowModalThenDo, as would be better, because multiple
+                    //        errors may occur in this loop. See https://github.com/vslavik/poedit/issues/748
+                    if (paths.size() == 1)
+                        err->ShowWindowModalThenDo([err](int){});
+                    else
+                        err->ShowModal();
                 }
             }
             UpdateStats();
